/*
 * Copyright (c) 2011-2015 BlackBerry Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "applicationui.hpp"
#include "TaskModel.h"

#include <bb/cascades/Application>
#include <bb/cascades/QmlDocument>
#include <bb/cascades/AbstractPane>
#include <bb/cascades/LocaleHandler>
#include <bb/cascades/pickers/FilePicker>
#include <bb/cascades/SceneCover>
#include <bb/ApplicationInfo>

using namespace bb::cascades;

ApplicationUI::ApplicationUI() :
        QObject()
{
    // prepare the invoke manager
    invokeManager = new bb::system::InvokeManager(this);
    connect(invokeManager, SIGNAL(invoked(const bb::system::InvokeRequest&)),
            this, SLOT(onInvoke(const bb::system::InvokeRequest&)));

    // prepare the localization
    m_pTranslator = new QTranslator(this);
    m_pLocaleHandler = new LocaleHandler(this);

    bool res = QObject::connect(m_pLocaleHandler, SIGNAL(systemLanguageChanged()), this, SLOT(onSystemLanguageChanged()));
    // This is only available in Debug builds
    Q_ASSERT(res);
    // Since the variable is not used in the app, this is added to avoid a
    // compiler warning
    Q_UNUSED(res);

    // initial load
    onSystemLanguageChanged();

    qmlRegisterType<TaskModel>("com.monkeystew.taskmodel", 1, 0, "TaskModel");
    qmlRegisterType<SceneCover>("bb.cascades", 1, 0, "SceneCover");
    qmlRegisterUncreatableType<AbstractCover>("bb.cascades", 1, 0, "AbstractCover",
            "An AbstractCover cannot be created.");

    // Create scene document from main.qml asset, the parent is set
    // to ensure the document gets destroyed properly at shut down.
    QmlDocument *qml = QmlDocument::create("asset:///main.qml").parent(this);
    qml->setContextProperty("_Taskslayer", this);

    // Create root object for the UI
    AbstractPane *root = qml->createRootObject<AbstractPane>();

    // Set created root object as the application scene
    Application::instance()->setScene(root);

    bb::ApplicationInfo appinfo;
    qDebug() << "APP VER_ " << appinfo.version();
    root->setProperty("appversion", appinfo.version());
}

void ApplicationUI::onSystemLanguageChanged()
{
    QCoreApplication::instance()->removeTranslator(m_pTranslator);
    // Initiate, load and install the application translation files.
    QString locale_string = QLocale().name();
    QString file_name = QString("RenamedTodo_%1").arg(locale_string);
    if (m_pTranslator->load(file_name, "app/native/qm")) {
        QCoreApplication::instance()->installTranslator(m_pTranslator);
    }
}

void ApplicationUI::onInvoke(const bb::system::InvokeRequest& request)
{
    if (request.action() == "bb.action.SHARE") {
        Q_EMIT addNewTask(QString::fromUtf8(request.data()));
    } else if (request.action() == "bb.action.SEARCH.EXTENDED") {
        Q_EMIT searchTaskList(QString::fromUtf8(request.data()));
    }
}

void ApplicationUI::getSupport(const int target)
{
    bb::system::InvokeRequest request;

    switch(target)
    {
        case 0:
            request.setTarget("sys.pim.uib.email.hybridcomposer");
            request.setAction("bb.action.COMPOSE");
            request.setMimeType("message/rfc822");
            request.setUri(QUrl("mailto:rtd@monkeystew.com?subject=Renamed Todo for BlackBerry 10"));
            invokeManager->invoke(request);
            break;
    }
}
